@@ -2,6 +2,7 @@ package RandomFileMethodAllTests;
 use base qw/RandomFileSimpleDirOption
             RandomFileCheckOption
 			RandomFileRecursiveOption
-			RandomFilePassesPathsToCheckRoutine/;
+			RandomFilePassesPathsToCheckRoutine
+            RandomFileWithUnknownParameters/;
 
 1;
